@@ -11,6 +11,7 @@ from hdx.utilities.loader import load_yaml
 from hdx.data.hdxobject import HDXError
 from hdx.data.showcase import Showcase
 from hdx.hdx_configuration import Configuration
+from .test_vocabulary import vocabulary_mockshow
 from . import MockResponse
 
 showcase_resultdict = {
@@ -27,17 +28,17 @@ showcase_resultdict = {
     'resources': [],
     'tags': [
         {
-            'vocabulary_id': '57f71f5f-adb0-48fd-ab2c-6b93b9d30332',
+            'vocabulary_id': '4381925f-0ae9-44a3-b30d-cae35598757b',
             'state': 'active',
-            'display_name': 'economy',
-            'id': 'c69c6fa1-7b2d-403e-a386-c57272da505d',
-            'name': 'economy'
+            'display_name': 'economics',
+            'id': 'e1ff4b78-efcf-40e7-888b-7342169068e1',
+            'name': 'economics'
         },
         {
-            'vocabulary_id': '57f71f5f-adb0-48fd-ab2c-6b93b9d30332',
+            'vocabulary_id': '4381925f-0ae9-44a3-b30d-cae35598757b',
             'state': 'active',
             'display_name': 'health',
-            'id': 'cfc3fb43-78a5-45e0-8bac-fbb81d00d211',
+            'id': '8a43b269-78cb-4a85-a4ce-7e3e928bc487',
             'name': 'health'
         }
     ],
@@ -55,12 +56,13 @@ showcase_resultdict = {
     'name': 'showcase-1'
 }
 
-datasetsdict = load_yaml(join('tests', 'fixtures', 'dataset_all_results.yml'))
+datasetsdict = load_yaml(join('tests', 'fixtures', 'dataset_search_results.yml'))
+allsearchdict = load_yaml(join('tests', 'fixtures', 'showcase_all_search_results.yml'))
 
 
 def mockshow(url, datadict):
     if 'package_list' in url:
-        result = json.dumps(datasetsdict)
+        result = json.dumps(datasetsdict['results'])
         return MockResponse(200,
                             '{"success": true, "result": %s, "help": "http://test-data.humdata.org/api/3/action/help_show?name=ckanext_showcase_package_list"}' % result)
     if '_show' not in url:
@@ -80,6 +82,52 @@ def mockshow(url, datadict):
                         '{"success": false, "error": {"message": "Not found", "__type": "Not Found Error"}, "help": "http://test-data.humdata.org/api/3/action/help_show?name=ckanext_showcase_show"}')
 
 
+def mockallsearch(url, datadict):
+    if 'search' not in url:
+        return MockResponse(404,
+                            '{"success": false, "error": {"message": "TEST ERROR: Not search", "__type": "TEST ERROR: Not Search Error"}, "help": "http://test-data.humdata.org/api/3/action/help_show?name=package_search"}')
+    if 'metadata_modified' in datadict['fq']:
+        newsearchdict = copy.deepcopy(allsearchdict)
+        newsearchdict['results'] = [newsearchdict['results'][0]]
+        return MockResponse(200,
+                            '{"success": true, "result": %s, "help": "http://test-data.humdata.org/api/3/action/help_show?name=package_search"}' % json.dumps(
+                                newsearchdict))
+    if datadict['q'] == 'ACLED':
+        newsearchdict = copy.deepcopy(allsearchdict)
+        if datadict['rows'] == 11:
+            newsearchdict['results'].append(newsearchdict['results'][0])
+        elif datadict['rows'] == 6:
+            if datadict['start'] == 2:
+                newsearchdict['results'] = newsearchdict['results'][2:8]
+        elif datadict['rows'] == 5:
+            if datadict['start'] == 0:
+                newsearchdict['count'] = 5
+                newsearchdict['results'] = newsearchdict['results'][:5]
+            elif datadict['start'] == 5:
+                newsearchdict['count'] = 6  # return wrong count
+                newsearchdict['results'] = newsearchdict['results'][:5]
+            else:
+                newsearchdict['count'] = 0
+                newsearchdict['results'] = list()
+        result = json.dumps(newsearchdict)
+        return MockResponse(200, '{"success": true, "result": %s, "help": "http://test-data.humdata.org/api/3/action/help_show?name=package_search"}' % result)
+    if datadict['q'] == '*:*':
+        newsearchdict = copy.deepcopy(allsearchdict)
+        newsearchdict['results'].extend(copy.deepcopy(newsearchdict['results']))
+        for i, x in enumerate(newsearchdict['results']):
+            x['id'] = '%s%d' % (x['id'], i)
+        return MockResponse(200,
+                            '{"success": true, "result": %s, "help": "http://test-data.humdata.org/api/3/action/help_show?name=package_search"}' % json.dumps(
+                                newsearchdict))
+    if datadict['q'] == '"':
+        return MockResponse(404,
+                            '{"success": false, "error": {"message": "Validation Error", "__type": "Validation Error"}, "help": "http://test-data.humdata.org/api/3/action/help_show?name=package_search"}')
+    if datadict['q'] == 'ajyhgr':
+        return MockResponse(200,
+                            '{"success": true, "result": {"count": 0, "results": []}, "help": "http://test-data.humdata.org/api/3/action/help_show?name=package_search"}')
+    return MockResponse(404,
+                        '{"success": false, "error": {"message": "Not found", "__type": "Not Found Error"}, "help": "http://test-data.humdata.org/api/3/action/help_show?name=package_search"}')
+
 
 class TestShowcase:
     showcase_data = {
@@ -127,13 +175,17 @@ class TestShowcase:
             @staticmethod
             def post(url, data, headers, files, allow_redirects, auth=None):
                 datadict = json.loads(data.decode('utf-8'))
+                if 'vocabulary' in url:
+                    return vocabulary_mockshow(url, datadict)
                 if url.endswith('show') or 'list' in url:
                     return mockshow(url, datadict)
                 if 'create' not in url:
                     return MockResponse(404,
                                         '{"success": false, "error": {"message": "TEST ERROR: Not create", "__type": "TEST ERROR: Not Create Error"}, "help": "http://test-data.humdata.org/api/3/action/help_show?name=ckanext_showcase_create"}')
 
-                result = json.dumps(showcase_resultdict)
+                resultdictcopy = copy.deepcopy(showcase_resultdict)
+                resultdictcopy['state'] = datadict['state']
+                result = json.dumps(resultdictcopy)
                 if datadict['title'] == 'MyShowcase1':
                     return MockResponse(200,
                                         '{"success": true, "result": %s, "help": "http://test-data.humdata.org/api/3/action/help_show?name=ckanext_showcase_create"}' % result)
@@ -155,6 +207,8 @@ class TestShowcase:
             @staticmethod
             def post(url, data, headers, files, allow_redirects, auth=None):
                 datadict = json.loads(data.decode('utf-8'))
+                if 'vocabulary' in url:
+                    return vocabulary_mockshow(url, datadict)
                 if url.endswith('show') or 'list' in url:
                     return mockshow(url, datadict)
                 if 'update' not in url:
@@ -200,6 +254,16 @@ class TestShowcase:
 
         Configuration.read().remoteckan().session = MockSession()
 
+    @pytest.fixture(scope='function')
+    def allsearch(self):
+        class MockSession(object):
+            @staticmethod
+            def post(url, data, headers, files, allow_redirects, auth=None):
+                datadict = json.loads(data.decode('utf-8'))
+                return mockallsearch(url, datadict)
+
+        Configuration.read().remoteckan().session = MockSession()
+
     def test_read_from_hdx(self, configuration, read):
         showcase = Showcase.read_from_hdx('05e392bf-04e0-4ca6-848c-4e87bba10746')
         assert showcase['id'] == '05e392bf-04e0-4ca6-848c-4e87bba10746'
@@ -222,6 +286,7 @@ class TestShowcase:
         showcase = Showcase(showcase_data)
         showcase.create_in_hdx()
         assert showcase['id'] == '05e392bf-04e0-4ca6-848c-4e87bba10746'
+        assert showcase['state'] == 'active'
 
         showcase_data['title'] = 'MyShowcase2'
         showcase = Showcase(showcase_data)
@@ -251,9 +316,11 @@ class TestShowcase:
         showcase.update_in_hdx()
         assert showcase['name'] == 'TEST1'
         assert showcase['notes'] == 'lalalala'
+        assert showcase['state'] == 'active'
         expected = copy.deepcopy(showcase_resultdict)
         expected['notes'] = 'lalalala'
         expected['name'] = 'TEST1'
+        expected['tags'] = [{'name': 'economics', 'vocabulary_id': '4381925f-0ae9-44a3-b30d-cae35598757b'}, {'name': 'health', 'vocabulary_id': '4381925f-0ae9-44a3-b30d-cae35598757b'}]
         assert showcase.get_old_data_dict() == expected
 
         showcase['name'] = 'NOTEXIST'
@@ -271,6 +338,7 @@ class TestShowcase:
         showcase.create_in_hdx()
         assert showcase['name'] == 'TEST1'
         assert showcase['notes'] == 'My Showcase'
+        assert showcase['state'] == 'active'
 
     def test_delete_from_hdx(self, configuration, post_delete):
         showcase = Showcase.read_from_hdx('05e392bf-04e0-4ca6-848c-4e87bba10746')
@@ -302,12 +370,12 @@ class TestShowcase:
         showcase = Showcase(showcase_data)
         assert showcase.get_tags() == ['economy', 'health']
         showcase.add_tag('wash')
-        assert showcase.get_tags() == ['economy', 'health', 'wash']
+        assert showcase.get_tags() == ['economy', 'health', 'water sanitation and hygiene - wash']
         showcase.add_tags(['sanitation'])
-        assert showcase.get_tags() == ['economy', 'health', 'wash', 'sanitation']
-        result = showcase.remove_tag('wash')
+        assert showcase.get_tags() == ['economy', 'health', 'water sanitation and hygiene - wash']
+        result = showcase.remove_tag('water sanitation and hygiene - wash')
         assert result is True
-        assert showcase.get_tags() == ['economy', 'health', 'sanitation']
+        assert showcase.get_tags() == ['economy', 'health']
         showcase['tags'] = None
         result = showcase.remove_tag('wash')
         assert result is False
@@ -316,8 +384,8 @@ class TestShowcase:
         showcase = Showcase.read_from_hdx('05e392bf-04e0-4ca6-848c-4e87bba10746')
         datasets = showcase.get_datasets()
         assert len(datasets) == 10
-        assert datasets[0].data == datasetsdict[0]
-        dict4 = copy.deepcopy(datasetsdict[4])
+        assert datasets[0].data == datasetsdict['results'][0]
+        dict4 = copy.deepcopy(datasetsdict['results'][4])
         del dict4['resources']
         assert datasets[4].data == dict4
         TestShowcase.association = None
@@ -338,3 +406,23 @@ class TestShowcase:
         with pytest.raises(HDXError):
             showcase.add_dataset(123)
 
+    def test_search_in_hdx(self, configuration, allsearch):
+        showcases = Showcase.search_in_hdx('ACLED')
+        assert len(showcases) == 10
+        showcases = Showcase.search_in_hdx('ACLED', offset=2, limit=6)
+        assert len(showcases) == 6
+        showcases = Showcase.search_in_hdx(fq='metadata_modified:[2018-01-01T00:00:00.000Z TO NOW]')
+        assert len(showcases) == 1
+        showcases = Showcase.search_in_hdx('ajyhgr')
+        assert len(showcases) == 0
+        with pytest.raises(HDXError):
+            Showcase.search_in_hdx('"')
+        with pytest.raises(HDXError):
+            Showcase.search_in_hdx('ACLED', rows=11)
+        with pytest.raises(HDXError):
+            # Test returned row counts per page mismatch (wrong count of 6 purposely in mocksearch)
+            Showcase.search_in_hdx('ACLED', page_size=5)
+
+    def test_get_all_showcases(self, configuration, allsearch):
+        showcases = Showcase.get_all_showcases()
+        assert len(showcases) == 20
